#!/usr/bin/env python
import os
import sys


from . import sort_requirements


def main():
    files = [os.path.abspath(f) for f in sys.argv[1:]]
    for path in files:
        with open(path, "r") as f:
            data = sort_requirements(f.read())
        with open(path, "w") as f:
            f.write(data)


if __name__ == "__main__":
    main()



import re


VERSION = (1, 0, 0)
DEPS_RE = r"(.+?)==([^\\\n]+)((?:\\\n[^\\\n]+)*)"


__version__ = ".".join(str(v) for v in VERSION)


def sort_requirements(requirements):
    matches = re.findall(DEPS_RE, requirements)
    data = re.sub(DEPS_RE, "{}", requirements)
    matches = sorted(matches, key=lambda d: d[0].lower())

    deps = []
    for m in matches:
        dep = "{}=={}".format(*m[0:2])
        if m[2]:
            dep += m[2]
        deps.append(dep)

    data = data.format(*deps)
    return data
